@@ -97,7 +97,11 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
 
 
 def set_query_dc_value(query_dc: (QueryDict, dict), new_dc: dict):
-    assert isinstance(query_dc, QueryDict), 'query_dc必须是QueryDict类型!'
+    assert isinstance(query_dc, (dict, QueryDict)), 'query_dc必须是`QueryDict`或`dict`类型!'
+    if isinstance(query_dc, dict):
+        query_dc.update(new_dc)
+        return query_dc
+
     query_dc._mutable = True
     for key, value in new_dc.items():
         ls = value if isinstance(value, (tuple, list)) else [value]
